/**
 * Main application component.
 * Sets up the main layout using Header, Page, and Footer components.
 * Includes routing for different pages.
 */
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import { lazy, Suspense } from 'react';
import Header from './components/Header';
import Page from './pages/Page';
import Footer from './components/Footer';
import SEO from './components/SEO';
import Analytics from './components/Analytics';
import { StagewiseToolbar } from '@stagewise/toolbar-react';
import { ReactPlugin } from '@stagewise-plugins/react';

// Lazy load admin components for better performance
const DashboardPage = lazy(() => import('./pages/admin/DashboardPage'));
const AdminLayout = lazy(() => import('./components/admin/AdminLayout'));
const NewCasePage = lazy(() => import('./pages/admin/NewPage'));
const EditCasePage = lazy(() => import('./pages/admin/EditPage'));
const LoginPage = lazy(() => import('./pages/admin/LoginPage'));
const MediaManagerPage = lazy(() => import('./pages/admin/MediaManagerPage'));

import NotFoundPage from './pages/NotFoundPage';
import ErrorBoundary from './components/ErrorBoundary';
import { ToastProvider } from './contexts/ToastContext';
import { AuthProvider } from './contexts/AuthContext';
import './App.css';

function App() {
  return (
    <Router>
      <AuthProvider>
        <ToastProvider>
          <ErrorBoundary>
            <SEO />
            <Analytics 
              measurementId={import.meta.env.VITE_GA_MEASUREMENT_ID || "G-5T68SH1TE5"}
              cookieConsentRequired={true}
              debugMode={import.meta.env.DEV}
            />
            <div className="app-container">
              <StagewiseToolbar 
                config={{
                  plugins: [ReactPlugin]
                }}
              />
              <Header />
              <main className="main-content">
                <ErrorBoundary>
                  <Routes>
                    {/* Public Routes */}
                    <Route path="/" element={<Page />} />
                    <Route path="/clients" element={<Page />} />
                    <Route path="/clients/:caseId" element={<Page />} />
                    <Route path="/cases/:caseId" element={<Page />} />

                    {/* Admin Routes - Lazy loaded */}
                    <Route path="/admin/login" element={
                      <Suspense fallback={<div>Loading...</div>}>
                        <LoginPage />
                      </Suspense>
                    } />
                    <Route path="/admin" element={
                      <Suspense fallback={<div>Loading admin...</div>}>
                        <AdminLayout />
                      </Suspense>
                    }>
                      <Route index element={
                        <Suspense fallback={<div>Loading dashboard...</div>}>
                          <DashboardPage />
                        </Suspense>
                      } />
                      <Route path="dashboard" element={
                        <Suspense fallback={<div>Loading dashboard...</div>}>
                          <DashboardPage />
                        </Suspense>
                      } />
                      <Route path="cases/new" element={
                        <Suspense fallback={<div>Loading editor...</div>}>
                          <NewCasePage />
                        </Suspense>
                      } />
                      <Route path="cases/edit/:id" element={
                        <Suspense fallback={<div>Loading editor...</div>}>
                          <EditCasePage />
                        </Suspense>
                      } />
                      <Route path="media" element={
                        <Suspense fallback={<div>Loading media manager...</div>}>
                          <MediaManagerPage />
                        </Suspense>
                      } />
                    </Route>

                    {/* Catch-all route for 404 */}
                    <Route path="*" element={<NotFoundPage />} />
                  </Routes>
                </ErrorBoundary>
              </main>
              <Footer />
            </div>
          </ErrorBoundary>
        </ToastProvider>
      </AuthProvider>
    </Router>
  );
}

export default App;
